@@ -3,11 +3,10 @@
 """telegram_menu demonstrator."""
 
 import logging
-import time
 from pathlib import Path
 
 from telegram_menu import TelegramMenuSession
-from tests.test_connection import StartMessage, init_logger
+from tests.test_connection import MyNavigationHandler, StartMessage, init_logger
 
 
 def run() -> None:
@@ -17,7 +16,9 @@ def run() -> None:
         api_key = key_h.read().strip()
 
     logging.info(" >> Start the demo and wait forever, quit with CTRL+C...")
-    TelegramMenuSession(api_key).start(StartMessage, idle=True)
+    TelegramMenuSession(api_key).start(
+        start_message_class=StartMessage, navigation_handler_class=MyNavigationHandler, idle=True
+    )
 
 
 if __name__ == "__main__":
